@@ -20,7 +20,6 @@ import pele_platform.Utilities.Helpers.metrics as mt
 import pele_platform.Utilities.Helpers.external_files as ext
 import pele_platform.Utilities.Helpers.solventOBCParamsGenerator as obc
 import pele_platform.Analysis.plots as pt
-import pele_platform.Analysis.pdf_report as pr
 
 
 
@@ -35,7 +34,7 @@ def run_adaptive(args):
 
     if env.adaptive_restart:
         with helpers.cd(env.pele_dir):
-            adt.main(env.ad_ex_temp)
+            #adt.main(env.ad_ex_temp)
             env.logger.info("Simulation run succesfully (:\n\n")
 
     else:
@@ -183,10 +182,9 @@ def run_adaptive(args):
         env.logger.info("Simulation run succesfully (:\n\n")
 
     if env.analyse and not env.debug:
-        plots, poses, clusters = pt.analyse_simulation(env.report_name, env.traj_name[:-4]+"_", 
+        report = pt.analyse_simulation(env.report_name, env.traj_name[:-4]+"_", 
             os.path.join(env.pele_dir, env.output), env.residue, cpus=env.cpus,
             output_folder=env.pele_dir, clustering=env.perturbation, mae=env.mae,
             topology=env.topology)
-        pr.create_report(plots, clusters, poses, output=os.path.join(env.pele_dir, "summary_results.pdf"))
-
+        print("Pdf summary report succesfully writen to: {}".format(report))
     return env
